/**
 * @file Tree
 * @description 树形组件
 * @author fex
 */
/// <reference types="hoist-non-react-statics" />
import React from 'react';
import { Option, Options } from './Select';
import { ThemeProps } from '../theme';
import { LocaleProps } from '../locale';
interface TreeSelectorProps extends ThemeProps, LocaleProps {
    highlightTxt?: string;
    showIcon?: boolean;
    initiallyOpen?: boolean;
    unfoldedLevel?: number;
    showRadio?: boolean;
    multiple?: boolean;
    disabled?: boolean;
    withChildren?: boolean;
    onlyChildren?: boolean;
    labelField: string;
    valueField: string;
    iconField: string;
    unfoldedField: string;
    foldedField: string;
    disabledField: string;
    showOutline?: boolean;
    className?: string;
    itemClassName?: string;
    joinValues?: boolean;
    extractValue?: boolean;
    delimiter?: string;
    options: Options;
    value: any;
    onChange: Function;
    placeholder?: string;
    hideRoot?: boolean;
    rootLabel?: string;
    rootValue?: any;
    cascade?: boolean;
    selfDisabledAffectChildren?: boolean;
    minLength?: number;
    maxLength?: number;
    bultinCUD?: boolean;
    rootCreatable?: boolean;
    rootCreateTip?: string;
    creatable?: boolean;
    createTip?: string;
    onAdd?: (idx?: number | Array<number>, value?: any, skipForm?: boolean) => void;
    editable?: boolean;
    editTip?: string;
    onEdit?: (value: Option, origin?: Option, skipForm?: boolean) => void;
    removable?: boolean;
    removeTip?: string;
    onDelete?: (value: Option) => void;
    onDeferLoad?: (option: Option) => void;
}
interface TreeSelectorState {
    value: Array<any>;
    inputValue: string;
    addingParent: Option | null;
    isAdding: boolean;
    isEditing: boolean;
    editingItem: Option | null;
}
export declare class TreeSelector extends React.Component<TreeSelectorProps, TreeSelectorState> {
    static defaultProps: {
        showIcon: boolean;
        showOutline: boolean;
        initiallyOpen: boolean;
        unfoldedLevel: number;
        showRadio: boolean;
        multiple: boolean;
        disabled: boolean;
        withChildren: boolean;
        onlyChildren: boolean;
        labelField: string;
        valueField: string;
        iconField: string;
        unfoldedField: string;
        foldedField: string;
        disabledField: string;
        joinValues: boolean;
        extractValue: boolean;
        delimiter: string;
        hideRoot: boolean;
        rootLabel: string;
        rootValue: number;
        cascade: boolean;
        selfDisabledAffectChildren: boolean;
        rootCreateTip: string;
        createTip: string;
        editTip: string;
        removeTip: string;
    };
    unfolded: WeakMap<Object, boolean>;
    constructor(props: TreeSelectorProps);
    componentDidUpdate(prevProps: TreeSelectorProps): void;
    syncUnFolded(props: TreeSelectorProps): WeakMap<Object, boolean>;
    toggleUnfolded(node: any): void;
    isUnfolded(node: any): boolean | undefined;
    clearSelect(): void;
    handleSelect(node: any, value?: any): void;
    handleCheck(item: any, checked: boolean): void;
    handleAdd(parent?: Option | null): void;
    handleEdit(item: Option): void;
    handleRemove(item: Option): void;
    handleInputChange(e: React.ChangeEvent<HTMLInputElement>): void;
    handleConfirm(): void;
    handleCancel(): void;
    renderInput(prfix?: JSX.Element | null): JSX.Element;
    renderList(list: Options, value: Option[], uncheckable: boolean): {
        dom: Array<JSX.Element | null>;
        childrenChecked: number;
    };
    render(): JSX.Element;
}
declare const _default: {
    new (props: (Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
        showIcon: boolean;
        showOutline: boolean;
        initiallyOpen: boolean;
        unfoldedLevel: number;
        showRadio: boolean;
        multiple: boolean;
        disabled: boolean;
        withChildren: boolean;
        onlyChildren: boolean;
        labelField: string;
        valueField: string;
        iconField: string;
        unfoldedField: string;
        foldedField: string;
        disabledField: string;
        joinValues: boolean;
        extractValue: boolean;
        delimiter: string;
        hideRoot: boolean;
        rootLabel: string;
        rootValue: number;
        cascade: boolean;
        selfDisabledAffectChildren: boolean;
        rootCreateTip: string;
        createTip: string;
        editTip: string;
        removeTip: string;
    }, never>> & {
        locale?: string | undefined;
        translate?: ((str: string, ...args: any[]) => string) | undefined;
    }, keyof ThemeProps> & import("../theme").ThemeOutterProps) | Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
        showIcon: boolean;
        showOutline: boolean;
        initiallyOpen: boolean;
        unfoldedLevel: number;
        showRadio: boolean;
        multiple: boolean;
        disabled: boolean;
        withChildren: boolean;
        onlyChildren: boolean;
        labelField: string;
        valueField: string;
        iconField: string;
        unfoldedField: string;
        foldedField: string;
        disabledField: string;
        joinValues: boolean;
        extractValue: boolean;
        delimiter: string;
        hideRoot: boolean;
        rootLabel: string;
        rootValue: number;
        cascade: boolean;
        selfDisabledAffectChildren: boolean;
        rootCreateTip: string;
        createTip: string;
        editTip: string;
        removeTip: string;
    }, never>> & {
        locale?: string | undefined;
        translate?: ((str: string, ...args: any[]) => string) | undefined;
    }, keyof ThemeProps> & import("../theme").ThemeOutterProps>): {
        render(): JSX.Element;
        context: any;
        setState<K extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>) => {} | Pick<{}, K> | null) | Pick<{}, K> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps> & Readonly<{
            children?: React.ReactNode;
        }>;
        state: Readonly<{}>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        componentDidMount?(): void;
        shouldComponentUpdate?(nextProps: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): boolean;
        componentWillUnmount?(): void;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, prevState: Readonly<{}>): any;
        componentDidUpdate?(prevProps: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, prevState: Readonly<{}>, snapshot?: any): void;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): void;
    };
    new (props: Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
        showIcon: boolean;
        showOutline: boolean;
        initiallyOpen: boolean;
        unfoldedLevel: number;
        showRadio: boolean;
        multiple: boolean;
        disabled: boolean;
        withChildren: boolean;
        onlyChildren: boolean;
        labelField: string;
        valueField: string;
        iconField: string;
        unfoldedField: string;
        foldedField: string;
        disabledField: string;
        joinValues: boolean;
        extractValue: boolean;
        delimiter: string;
        hideRoot: boolean;
        rootLabel: string;
        rootValue: number;
        cascade: boolean;
        selfDisabledAffectChildren: boolean;
        rootCreateTip: string;
        createTip: string;
        editTip: string;
        removeTip: string;
    }, never>> & {
        locale?: string | undefined;
        translate?: ((str: string, ...args: any[]) => string) | undefined;
    }, keyof ThemeProps> & import("../theme").ThemeOutterProps, context: any): {
        render(): JSX.Element;
        context: any;
        setState<K extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>) => {} | Pick<{}, K> | null) | Pick<{}, K> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps> & Readonly<{
            children?: React.ReactNode;
        }>;
        state: Readonly<{}>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        componentDidMount?(): void;
        shouldComponentUpdate?(nextProps: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): boolean;
        componentWillUnmount?(): void;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, prevState: Readonly<{}>): any;
        componentDidUpdate?(prevProps: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, prevState: Readonly<{}>, snapshot?: any): void;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<Omit<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): void;
    };
    displayName: string;
    contextType: React.Context<string>;
    ComposedComponent: React.ComponentType<{
        new (props: (Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }) | Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>): {
            render(): JSX.Element;
            context: any;
            setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }> & Readonly<{
                children?: React.ReactNode;
            }>;
            state: Readonly<{}>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            componentDidMount?(): void;
            shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): boolean;
            componentWillUnmount?(): void;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>): any;
            componentDidUpdate?(prevProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
        };
        new (props: Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, context: any): {
            render(): JSX.Element;
            context: any;
            setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }> & Readonly<{
                children?: React.ReactNode;
            }>;
            state: Readonly<{}>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            componentDidMount?(): void;
            shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): boolean;
            componentWillUnmount?(): void;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>): any;
            componentDidUpdate?(prevProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
        };
        displayName: string;
        contextType: React.Context<string>;
        ComposedComponent: React.ComponentType<typeof TreeSelector>;
    } & import("hoist-non-react-statics").NonReactStatics<typeof TreeSelector, {}> & {
        ComposedComponent: typeof TreeSelector;
    }>;
} & import("hoist-non-react-statics").NonReactStatics<{
    new (props: (Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
        showIcon: boolean;
        showOutline: boolean;
        initiallyOpen: boolean;
        unfoldedLevel: number;
        showRadio: boolean;
        multiple: boolean;
        disabled: boolean;
        withChildren: boolean;
        onlyChildren: boolean;
        labelField: string;
        valueField: string;
        iconField: string;
        unfoldedField: string;
        foldedField: string;
        disabledField: string;
        joinValues: boolean;
        extractValue: boolean;
        delimiter: string;
        hideRoot: boolean;
        rootLabel: string;
        rootValue: number;
        cascade: boolean;
        selfDisabledAffectChildren: boolean;
        rootCreateTip: string;
        createTip: string;
        editTip: string;
        removeTip: string;
    }, never>> & {
        locale?: string | undefined;
        translate?: ((str: string, ...args: any[]) => string) | undefined;
    }) | Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
        showIcon: boolean;
        showOutline: boolean;
        initiallyOpen: boolean;
        unfoldedLevel: number;
        showRadio: boolean;
        multiple: boolean;
        disabled: boolean;
        withChildren: boolean;
        onlyChildren: boolean;
        labelField: string;
        valueField: string;
        iconField: string;
        unfoldedField: string;
        foldedField: string;
        disabledField: string;
        joinValues: boolean;
        extractValue: boolean;
        delimiter: string;
        hideRoot: boolean;
        rootLabel: string;
        rootValue: number;
        cascade: boolean;
        selfDisabledAffectChildren: boolean;
        rootCreateTip: string;
        createTip: string;
        editTip: string;
        removeTip: string;
    }, never>> & {
        locale?: string | undefined;
        translate?: ((str: string, ...args: any[]) => string) | undefined;
    }>): {
        render(): JSX.Element;
        context: any;
        setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }> & Readonly<{
            children?: React.ReactNode;
        }>;
        state: Readonly<{}>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        componentDidMount?(): void;
        shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): boolean;
        componentWillUnmount?(): void;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, prevState: Readonly<{}>): any;
        componentDidUpdate?(prevProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, prevState: Readonly<{}>, snapshot?: any): void;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): void;
    };
    new (props: Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
        showIcon: boolean;
        showOutline: boolean;
        initiallyOpen: boolean;
        unfoldedLevel: number;
        showRadio: boolean;
        multiple: boolean;
        disabled: boolean;
        withChildren: boolean;
        onlyChildren: boolean;
        labelField: string;
        valueField: string;
        iconField: string;
        unfoldedField: string;
        foldedField: string;
        disabledField: string;
        joinValues: boolean;
        extractValue: boolean;
        delimiter: string;
        hideRoot: boolean;
        rootLabel: string;
        rootValue: number;
        cascade: boolean;
        selfDisabledAffectChildren: boolean;
        rootCreateTip: string;
        createTip: string;
        editTip: string;
        removeTip: string;
    }, never>> & {
        locale?: string | undefined;
        translate?: ((str: string, ...args: any[]) => string) | undefined;
    }, context: any): {
        render(): JSX.Element;
        context: any;
        setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }> & Readonly<{
            children?: React.ReactNode;
        }>;
        state: Readonly<{}>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        componentDidMount?(): void;
        shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): boolean;
        componentWillUnmount?(): void;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, prevState: Readonly<{}>): any;
        componentDidUpdate?(prevProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, prevState: Readonly<{}>, snapshot?: any): void;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): void;
    };
    displayName: string;
    contextType: React.Context<string>;
    ComposedComponent: React.ComponentType<typeof TreeSelector>;
} & import("hoist-non-react-statics").NonReactStatics<typeof TreeSelector, {}> & {
    ComposedComponent: typeof TreeSelector;
}, {}> & {
    ComposedComponent: {
        new (props: (Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }) | Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>): {
            render(): JSX.Element;
            context: any;
            setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }> & Readonly<{
                children?: React.ReactNode;
            }>;
            state: Readonly<{}>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            componentDidMount?(): void;
            shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): boolean;
            componentWillUnmount?(): void;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>): any;
            componentDidUpdate?(prevProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
        };
        new (props: Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
            showIcon: boolean;
            showOutline: boolean;
            initiallyOpen: boolean;
            unfoldedLevel: number;
            showRadio: boolean;
            multiple: boolean;
            disabled: boolean;
            withChildren: boolean;
            onlyChildren: boolean;
            labelField: string;
            valueField: string;
            iconField: string;
            unfoldedField: string;
            foldedField: string;
            disabledField: string;
            joinValues: boolean;
            extractValue: boolean;
            delimiter: string;
            hideRoot: boolean;
            rootLabel: string;
            rootValue: number;
            cascade: boolean;
            selfDisabledAffectChildren: boolean;
            rootCreateTip: string;
            createTip: string;
            editTip: string;
            removeTip: string;
        }, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, context: any): {
            render(): JSX.Element;
            context: any;
            setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }> & Readonly<{
                children?: React.ReactNode;
            }>;
            state: Readonly<{}>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            componentDidMount?(): void;
            shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): boolean;
            componentWillUnmount?(): void;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>): any;
            componentDidUpdate?(prevProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "maxLength" | "minLength" | "options" | "placeholder" | "onChange" | "onDeferLoad" | "itemClassName" | "creatable" | "onAdd" | "editable" | "onEdit" | "removable" | "onDelete" | "highlightTxt" | "bultinCUD" | "rootCreatable"> & Partial<Pick<Omit<TreeSelectorProps, keyof LocaleProps>, "disabled" | "multiple" | "labelField" | "delimiter" | "valueField" | "joinValues" | "extractValue" | "showIcon" | "initiallyOpen" | "unfoldedLevel" | "showRadio" | "withChildren" | "onlyChildren" | "iconField" | "unfoldedField" | "foldedField" | "disabledField" | "showOutline" | "hideRoot" | "rootLabel" | "rootValue" | "cascade" | "selfDisabledAffectChildren" | "rootCreateTip" | "createTip" | "editTip" | "removeTip">> & Partial<Pick<{
                showIcon: boolean;
                showOutline: boolean;
                initiallyOpen: boolean;
                unfoldedLevel: number;
                showRadio: boolean;
                multiple: boolean;
                disabled: boolean;
                withChildren: boolean;
                onlyChildren: boolean;
                labelField: string;
                valueField: string;
                iconField: string;
                unfoldedField: string;
                foldedField: string;
                disabledField: string;
                joinValues: boolean;
                extractValue: boolean;
                delimiter: string;
                hideRoot: boolean;
                rootLabel: string;
                rootValue: number;
                cascade: boolean;
                selfDisabledAffectChildren: boolean;
                rootCreateTip: string;
                createTip: string;
                editTip: string;
                removeTip: string;
            }, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
        };
        displayName: string;
        contextType: React.Context<string>;
        ComposedComponent: React.ComponentType<typeof TreeSelector>;
    } & import("hoist-non-react-statics").NonReactStatics<typeof TreeSelector, {}> & {
        ComposedComponent: typeof TreeSelector;
    };
};
export default _default;
